@@ -1,4 +1,4 @@
-evalSummaryFunction <- function(y, ctrl, lev, metric, method) {
+evalSummaryFunction <- function(y, wts, ctrl, lev, metric, method) {
   ## get phoney performance to obtain the names of the outputs
   testOutput <- data.frame(pred = sample(y, min(10, length(y))),
                            obs = sample(y, min(10, length(y))))
@@ -11,6 +11,7 @@ evalSummaryFunction <- function(y, ctrl, lev, metric, method) {
     if(metric == "ROC" & !ctrl$classProbs)
       stop("train()'s use of ROC codes requires class probabilities. See the classProbs option of trainControl()")
   }
+  if(!is.null(wts)) testOutput$weights <- sample(wts, min(10, length(wts)))
   ctrl$summaryFunction(testOutput, lev, method)
 }
 
